pub(super) fn coerce_arg(arg: &Expr, expected: WgslType, ctx: &mut WalkCtx<'_>)
Emit an edit on arg that converts its inferred type to expected. No-op when both types agree or either is unknown / non-scalar-vec.
arg
expected